import { Component, Input } from "@angular/core";

import { I18nService } from "../../services/internationalisation/internationalisation.service";

@Component({
    selector: "quicknav",
    templateUrl: "./quicknav.component.html",
    styleUrls: [
        "./quicknav.component.scss"
    ]
})
export class QuicknavComponent {

    @Input()
    public items: string[];

    @Input()
    public currentItem: string;

    @Input()
    public align: string;

    private prefix = "qn_";

    public constructor(
        private i18nService: I18nService
    ) {
        this.items = [];
        this.currentItem = "";
        this.align = "center";
    }

    public get id() {
        return this.prefix + this.currentItem;
    }

    public get hasItems() {
        return this.items.length > 0;
    }

    public get alignStyle() {
        return {
            "text-align": this.align
        };
    }

    public label(item: string = "") {
        return this.i18nService.localizeText("INFO_QUICKNAV_" + item.toUpperCase());
    }

    public isCurrent(item: string) {
        return item === this.currentItem;
    }

    public scrollTo(item: string) {
        // https://stackoverflow.com/a/56391657/5986614
        const element = document.getElementById(this.prefix + item);
        if (element) {
            const yCoordinate = element.getBoundingClientRect().top + window.pageYOffset;
            // element.scrollIntoView({behavior: "smooth", block: "start", inline: "nearest"});
            window.scrollTo({
                top: yCoordinate - 60, // substract a little more than navbar height
                behavior: "smooth"
            });
        }
    }
}
